@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DjsuperadminConfig(AppConfig):
-    name = 'djsuperadmin'
+    name = "djsuperadmin"
